==> juce_8.0.3+ds.orig.tar.xz: JUCE-8.0.3/modules/juce_animation/animation/juce_VBlankAnimatorUpdater.h <==
/*
  ==============================================================================

   This file is part of the JUCE framework.
   Copyright (c) Raw Material Software Limited

   JUCE is an open source framework subject to commercial or open source
   licensing.

   By downloading, installing, or using the JUCE framework, or combining the
   JUCE framework with any other source code, object code, content or any other
   copyrightable work, you agree to the terms of the JUCE End User Licence
   Agreement, and all incorporated terms including the JUCE Privacy Policy and
   the JUCE Website Terms of Service, as applicable, which will bind you. If you
   do not agree to the terms of these agreements, we will not license the JUCE
   framework to you, and you must discontinue the installation or download
   process and cease use of the JUCE framework.

   JUCE End User Licence Agreement: https://juce.com/legal/juce-8-licence/
   JUCE Privacy Policy: https://juce.com/juce-privacy-policy
   JUCE Website Terms of Service: https://juce.com/juce-website-terms-of-service/

   Or:

   You may also use this code under the terms of the AGPLv3:
   https://www.gnu.org/licenses/agpl-3.0.en.html

   THE JUCE FRAMEWORK IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL
   WARRANTIES, WHETHER EXPRESSED OR IMPLIED, INCLUDING WARRANTY OF
   MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, ARE DISCLAIMED.

  ==============================================================================
*/

namespace juce
{

/**
    Similar to AnimatorUpdater, but automatically calls update() whenever the screen refreshes.

    @tags{Animations}
*/
class JUCE_API  VBlankAnimatorUpdater : private AnimatorUpdater
{
public:
    /** Constructs a VBlankAnimatorUpdater that is synchronised to the refresh rate of the monitor
        that the provided Component is being displayed on.
    */
    explicit VBlankAnimatorUpdater (Component* c) : vBlankAttachment (c, [this] { update(); })
    {
    }

    using AnimatorUpdater::addAnimator, AnimatorUpdater::removeAnimator;

private:
    VBlankAttachment vBlankAttachment;
};

} // namespace juce

==> juce_8.0.6+ds.orig.tar.xz: JUCE-8.0.6/modules/juce_animation/animation/juce_VBlankAnimatorUpdater.h <==
/*
  ==============================================================================

   This file is part of the JUCE framework.
   Copyright (c) Raw Material Software Limited

   JUCE is an open source framework subject to commercial or open source
   licensing.

   By downloading, installing, or using the JUCE framework, or combining the
   JUCE framework with any other source code, object code, content or any other
   copyrightable work, you agree to the terms of the JUCE End User Licence
   Agreement, and all incorporated terms including the JUCE Privacy Policy and
   the JUCE Website Terms of Service, as applicable, which will bind you. If you
   do not agree to the terms of these agreements, we will not license the JUCE
   framework to you, and you must discontinue the installation or download
   process and cease use of the JUCE framework.

   JUCE End User Licence Agreement: https://juce.com/legal/juce-8-licence/
   JUCE Privacy Policy: https://juce.com/juce-privacy-policy
   JUCE Website Terms of Service: https://juce.com/juce-website-terms-of-service/

   Or:

   You may also use this code under the terms of the AGPLv3:
   https://www.gnu.org/licenses/agpl-3.0.en.html

   THE JUCE FRAMEWORK IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL
   WARRANTIES, WHETHER EXPRESSED OR IMPLIED, INCLUDING WARRANTY OF
   MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, ARE DISCLAIMED.

  ==============================================================================
*/

namespace juce
{

/**
    Similar to AnimatorUpdater, but automatically calls update() whenever the screen refreshes.

    @tags{Animations}
*/
class JUCE_API  VBlankAnimatorUpdater : private AnimatorUpdater
{
public:
    /** Constructs a VBlankAnimatorUpdater that is synchronised to the refresh rate of the monitor
        that the provided Component is being displayed on.
    */
    explicit VBlankAnimatorUpdater (Component* c)
        : vBlankAttachment (c, [this] (double timestampSec)
                               {
                                   update (timestampSec * 1000.0);
                               })
    {
    }

    using AnimatorUpdater::addAnimator, AnimatorUpdater::removeAnimator;

private:
    VBlankAttachment vBlankAttachment;
};

} // namespace juce
